/*
 * Segment 5 Intelligente Analyseverfahren, SWE 5.2 Straßensubsegmentanalyse
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.subsegana.subsegana;

import java.util.ResourceBundle;
import java.util.logging.Level;

import de.bsvrz.sys.funclib.bitctrl.daf.LogNachricht;
import de.bsvrz.sys.funclib.debug.Debug;
import de.bsvrz.sys.funclib.operatingMessage.MessageGrade;

/**
 * Versorgt die Applikation mit lokalisierten Benutzernachrichten.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 */
public enum SubSegAnaMsg implements LogNachricht {

	/**
	 * Parameter: 1) Systemobjekt, 2) Attributgruppe, 3) Fuzzy-Wert, 4)
	 * Fehlermeldung.
	 */
	ErrorBeimSendenFuzzyWert(Debug.ERROR),

	/** Parameter: 1) Systemobjekt, 2) Störfallindikator, 3) Fehlermeldung. */
	ErrorBeimSendenStoerfall(Debug.ERROR),

	/** Parameter: 1) Systemobjekt, 2) Attributgruppe, 3) Fehlermeldung. */
	ErrorBeimAnmeldenQuelleFuzzyWert(Debug.ERROR),

	/** Parameter: 1) Systemobjekt, 2) Fehlermeldung. */
	ErrorBeimAnmeldenQuelleStoerfall(Debug.ERROR),

	/** Parameter: 1) Systemobjekt, 2) Fehlermeldung. */
	ErrorInWissensbasis(Debug.ERROR),

	/** Parameter: 1) Systemobjekt, 2) Fuzzy-Paramaterattributgruppe. */
	ErrorUngueltigenParameterEmpfangen(Debug.ERROR),

	/** Parameter: 1) Thread, 2) Stack Trace. */
	ErrorUnbekannterFehler(Debug.ERROR),

	/**
	 * Parameter: 1) Systemobjekt, 2) Fuzzy-Paramaterattributgruppe, 3)
	 * Messwertattributgruppe.
	 */
	WarningUngueltigerFuzzyParameter(Debug.WARNING),

	/** Parameter: 1) Systemobjekt, 2) Paramaterattributgruppe. */
	WarningUngueltigerWissensbasisParameter(Debug.WARNING),

	/** Ohne Paramater. */
	InfoSubSegAnaBereit(Debug.INFO),

	/** Ohne Paramater. */
	InfoStarteParameterVerwaltung(Debug.INFO),

	/** Ohne Paramater. */
	InfoStarteMesswertEmpfaenger(Debug.INFO),

	/** Ohne Paramater. */
	InfoStarteFuzzyfizierung(Debug.INFO),

	/** Ohne Paramater. */
	InfoStarteAggregation(Debug.INFO),

	/** Ohne Paramater. */
	InfoStarteRegelbasis(Debug.INFO),

	/** Ohne Paramater. */
	InfoBestimmeSystemobjekte(Debug.INFO),

	/** Parameter: 1) Anzahl Systemobjekte. */
	ConfigMesswertEmpfaengerBereit(Debug.CONFIG),

	/** Parameter: 1) Anzahl Systemobjekte, 2) Anzahl Fuzzy-Werte. */
	ConfigFuzzyfizierungBereit(Debug.CONFIG),

	/** Parameter: 1) Anzahl Systemobjekte, 2) Anzahl Parameter. */
	ConfigParameterVerwaltungBereit(Debug.CONFIG),

	/** Parameter: 1) Anzahl Straßenteilsegmente. */
	ConfigAggregationBereit(Debug.CONFIG),

	/**
	 * Parameter: 1) Anzahl Systemobjekte, 2) Anzahl beobachteter Fuzzy-Werte,
	 * 3) Anzahl sendender Fuzzy-Werte, 4) Anzahl Störfallindikatoren.
	 */
	ConfigRegelbasisBereit(Debug.CONFIG),

	/** Parameter: 1) Systemobjekt, 2) Messwert. */
	FineEmpfangeMesswert(Debug.FINE),

	/** Parameter: 1) Systemobjekt, 2) Fuzzy-Wert. */
	FineEmpfangeFuzzyWert(Debug.FINE),

	/** Parameter: 1) Systemobjekt, 2) Messwert. */
	FineNeuerAggregierterWert(Debug.FINE),

	/** Parameter: 1) Systemobjekt, 2) Fuzzy-Sets. */
	FineEmpfangeFuzzySetParameter(Debug.FINE),

	/**
	 * Parameter: 1) Systemobjekt, 2) Fuzzy-Wertattributgruppe, 3) Fuzzy-Wert.
	 */
	FineSendeFuzzyWert(Debug.FINE),

	/** Parameter: 1) Systemobjekt, 2) Störfallindikator. */
	FineSendeStoerfall(Debug.FINE),

	/** Parameter: 1) Systemobjekt, 2) Attributgruppe, 3) Aspekt. */
	FinerAnmeldenEmpfaengerMesswert(Debug.FINER),

	/** Parameter: 1) Systemobjekt, 2) Attributgruppe. */
	FinerAnmeldenEmpfaengerParameter(Debug.FINER),

	/** Parameter: 1) Systemobjekt, 2) Fuzzy-Wert. */
	FinerAnmeldenQuelleFuzzyWert(Debug.FINER),

	/** Parameter: 1) Systemobjekt. */
	FinerAnmeldenQuelleStoerfall(Debug.FINER),

	/** Parameter: 1) Systemobjekt, 2) Fuzzy-Wert. */
	FinerAnmeldenEmpfaengerFuzzyWert(Debug.FINER),

	/** Parameter: 1) Systemobjekt. */
	FinerIgnoriereUnbekanntesSystemObject(Debug.FINER),

	/** Parameter: 1) Systemobjekt, 2) Messwert. */
	FinerIgnoriereUnbekanntenMesswert(Debug.FINER);

	/** Das Resource-Bundle. */
	private static final ResourceBundle RESOURCE_BUNDLE = ResourceBundle
			.getBundle(SubSegAnaMsg.class.getCanonicalName());

	/** Die Eigenschaft {@code level}. */
	private final Level level;

	/**
	 * Initialisiert das Objekt.
	 *
	 * @param level
	 *            der Log-Level.
	 */
	private SubSegAnaMsg(final Level level) {
		this.level = level;
	}

	@Override
	public MessageGrade getBmvLevel() {
		if (level.equals(Debug.WARNING)) {
			return MessageGrade.WARNING;
		} else if (level.equals(Debug.ERROR)) {
			return MessageGrade.ERROR;
		}
		return null;

	}

	@Override
	public Level getLogLevel() {
		return level;
	}

	@Override
	public ResourceBundle getResourceBundle() {
		return RESOURCE_BUNDLE;
	}

	@Override
	public String toString() {
		return getResourceBundle().getString(name());
	}

}
